package de.fhdw.wtf.common.ast;

import de.fhdw.wtf.common.token.DummyToken;
import de.fhdw.wtf.common.token.Token;

/**
 * The reference for a {@link Constructor} that does not need to be existent when this reference is being parsed.
 *
 */
public final class ConstructorReference extends SyntaxObject {
	
	/**
	 * The state, that characterizes this {@link ConstructorReference}.
	 */
	private ConstructorReferenceState state;
	
	/**
	 * Creates a new {@link ConstructorReference}.
	 * 
	 * @param state
	 *            The state, that characterizes this {@link ConstructorReference}.
	 * @return a new instance of {@link ConstructorReference}.
	 */
	public static ConstructorReference create(final ConstructorReferenceState state) {
		final Token dummy = DummyToken.getInstance();
		return new ConstructorReference(state, dummy, dummy);
	}
	
	/**
	 * Creates a new {@link ConstructorReference}.
	 * 
	 * @param state
	 *            The state, that characterizes this {@link ConstructorReference}.
	 * @param firstToken
	 *            firstToken.
	 * @param lastToken
	 *            lastToken.
	 */
	private ConstructorReference(final ConstructorReferenceState state, final Token firstToken, final Token lastToken) {
		super(firstToken, lastToken);
		this.state = state;
	}
	
	@Override
	public String toString() {
		return this.getState().toString();
		// final StringBuilder result = new StringBuilder();
		// result.append(this.getParameters());
		// result.append(AstDescriptionConstants.SEMICOLON_TOKEN);
		// return result.toString();
	}
	
	@Override
	public boolean equals(final Object o) {
		if (o instanceof ConstructorReference) {
			final ConstructorReference other = (ConstructorReference) o;
			return this.getState().equals(other.getState());
		}
		return false;
	}
	
	@Override
	public int hashCode() {
		return this.getState().hashCode();
	}
	
	/**
	 * The state, that characterizes this {@link ConstructorReference}.
	 * 
	 * @return the state.
	 */
	public ConstructorReferenceState getState() {
		return this.state;
	}
	
	/**
	 * Changes the state of this to <code>newState</code>.
	 * 
	 * @param newState
	 *            - new State for {@link ConstructorReference}
	 */
	public void setState(final ConstructorReferenceState newState) {
		this.state = newState;
	}
}
