package de.fhdw.wtf.common.constants.walker;

import de.fhdw.wtf.common.ast.ConstructorReference;
import de.fhdw.wtf.common.ast.type.ByReferenceState;
import de.fhdw.wtf.common.ast.type.TypeProxy;

/**
 * Contains Exception Messages for Walker.
 */
public final class ExceptionConstants {
	
	/**
	 * Following Task forms a dependency on itself.
	 */
	public static final String CYCLIC_DEPENDENCY_MESSAGE = "Following Task forms a dependency on itself: ";
	
	/**
	 * Duplicate Attributename.
	 */
	public static final String DOUBLE_ATTRIBUTENAME_MESSAGE = "Duplicate Attributename: ";
	
	/**
	 * Duplicate Classname.
	 */
	public static final String DOUBLE_CLASSNAME_MESSAGE = "Duplicate Classname: ";
	
	/**
	 * Duplicate Groupname.
	 */
	public static final String DOUBLE_GROUPNAME_MESSAGE = "Duplicate Groupname: ";
	
	/**
	 * Found cycle in the inheritancestructur, because of.
	 */
	public static final String CYCLIC_INHERITANCE_MESSAGE = "Found cycle in the inheritancestructur, because of: ";
	
	/**
	 * Cyclic Part definition in GroupTask.
	 */
	public static final String CYCLIC_PART_DEFINITION_MESSAGE = "Cyclic Part definition in GroupTask";
	
	/**
	 * Invalid attribute modifier.
	 */
	public static final String INVALID_ATTRIBUTE_MODIFIER_MESSAGE = "Invalid attribute modifier: ";
	
	/**
	 * Base types can't have reverse getters.
	 */
	public static final String INVALID_SYMMETRIC_ATTRIBUTE_REASON = "Base types can't have reverse getters";
	
	/**
	 * Only abstract classes are allowed to have abstract operations.
	 */
	public static final String ABSTRACT_OPERATIONS_MESSAGE = "Only abstract classes "
			+ "are allowed to have abstract operations.";
	
	/**
	 * The names of the productElements must be pairwise distinct in every product. Duplicate ProductElementName.
	 */
	public static final String INVALID_PRODUCT_MESSAGE = "The names of the productElements "
			+ "must be pairwise distinct in every product. Duplicate ProductElementName: ";
	
	/**
	 * Invalid Overloading! Another operation has the same name and parametertypes!
	 */
	public static final String INVALID_OVERLOADING_MESSAGE = "Invalid Overloading! "
			+ "Another operation has the same name and parametertypes!";
	
	/**
	 * It is not allowed, that a Class extends a Basetype.
	 */
	public static final String BASETYPE_INHERITANCE_MESSAGE = "It is not allowed, that a Class extends a Basetype: ";
	
	/**
	 * Duplicate constructors within the same class are not allowed.
	 */
	public static final String DUPLICATE_CONSTRUCTOR_MESSAGE = "Duplicate copnstructor: ";
	
	/**
	 * A {@link ConstructorReference} has been found in an InvalidState.
	 */
	public static final String INVALID_CONSTRUCTOR_REFERENCE_MESSAGE_INVALID_STATE =
			"This constructor reference is in an invalid state: ";
	
	/**
	 * A constructor of class c cannot contain more than one reference if the only reference points to another
	 * constructor of c.
	 */
	public static final String INVALID_CONSTRUCTOR_REFERENCE_LIST_MESSAGE_WRONG_REFERENCE_VARIANTS =
			"Only super constructor references or exactly one reference "
					+ "to own classes constructor is allowed - constructor: ";
	
	/**
	 * A {@link ConstructorReference} does neither point to a super types constructor nor to a constructor of its
	 * surrounding class.
	 */
	public static final String INVALID_CONSTRUCTOR_REFERENCE_LIST_MESSAGE_NO_SUPERTYPE =
			"A constructor reference does neither point to a super types constructor "
					+ "nor to a constructor of its surrounding class: ";
	
	/**
	 * Not more than one {@link ConstructorReference} can point to a constructor of the same super type.
	 */
	public static final String INVALID_CONSTRUCTOR_REFERENCE_LIST_MESSAGE_MULTIPLE_REFERENCES_TO_ONE_SUPER_TYPE =
			"Two constructor references point to constructors of the same super type of the surrounding class: ";
	
	/**
	 * There has to be a reference to a constructor of each super type.
	 */
	public static final String INVALID_CONSTRUCTOR_REFERENCE_LIST_NOT_ENOUGTH_REFERENCES_TO_SUPER_TYPES =
			"Constructors of all super classes are not being referenced: ";
	
	/**
	 * A reference should not point to the same constructor as the one it is called from.
	 */
	public static final String INVALID_CONSTRUCTOR_REFERENCE_LIST_MESSAGE_REFERENCE_POINTS_TO_CALLING_CONSTRUCTOR =
			"The constructor should not call itself but another constructor of its class: ";
	
	/**
	 * A constructor can reference either exactly one constructor of its own class or exactly one constructor per super
	 * type of its class; not both variants at the same time.
	 */
	public static final String INVALID_CONSTRUCTOR_REFERENCE_LIST =
			"The constructor references super constructors as well as constructors of its own class.";
	
	/**
	 * {@link TypeProxy} objects can only return a target type if they are in a {@link ByReferenceState}.
	 */
	public static final String NO_TYPE_PROXY_TARGET_AVAILABLE =
			"The state of this TypeProxy is not the ByReferenceState. Therefore no target type can be returned.";
	
	/**
	 * Constructor of {@link ExceptionConstants}.
	 */
	private ExceptionConstants() {
	}
}
