package de.fhdw.wtf.common.token.keywords;

import de.fhdw.wtf.common.token.Position;
import de.fhdw.wtf.common.token.Token;

/**
 * Represents the "mutable"-modifier as a token in WTF.
 */
public final class MutableToken extends AttributeModifierToken {
	
	/**
	 * generated.
	 */
	private static final long serialVersionUID = 7226684020132331980L;
	
	/**
	 * Defines constant for hashCodeTemplate().
	 */
	private static final int HASHCODE_TEMPLATE_CONSTANT = 2612357;
	
	/**
	 * Defines constant "mutable" for {@link MutableToken}.
	 */
	private static final String TEXTUAL_REPRESENTATION = "mutable";
	
	/**
	 * Private constructor for {@link MutableToken}. Use create(...)-Factory instead!
	 * 
	 * @param position
	 *            represents the start position of an {@link MutableToken} in the original input.
	 */
	private MutableToken(final Position position) {
		super(position);
	}
	
	/**
	 * Factory method for {@link MutableToken}.
	 * 
	 * @param position
	 *            represents the start position of this {@link AttributeModifierToken} in the original input.
	 * @return a new instance of this {@link AttributeModifierToken}.
	 */
	public static MutableToken create(final Position position) {
		return new MutableToken(position);
	}
	
	@Override
	public int getLength() {
		return MutableToken.TEXTUAL_REPRESENTATION.length();
	}
	
	@Override
	public boolean isMutableToken() {
		return true;
	}
	
	@Override
	public boolean isAttributeModifierToken() {
		return true;
	}
	
	@Override
	protected boolean equalsTemplate(final Token t) {
		return t.isMutableToken();
	}
	
	@Override
	public String stringRepresentation() {
		return MutableToken.TEXTUAL_REPRESENTATION;
	}
	
	@Override
	protected int hashCodeTemplate() {
		return HASHCODE_TEMPLATE_CONSTANT;
	}
	
}
