package de.fhdw.wtf.common.token.symbols;

import de.fhdw.wtf.common.token.Position;
import de.fhdw.wtf.common.token.Token;

/**
 * Represents the colon symbol ':' as a token.
 */
public final class ColonToken extends SymbolToken {
	
	/**
	 * generated.
	 */
	private static final long serialVersionUID = -7996491532237820338L;
	
	/**
	 * Defines constant for hashCodeTemplate().
	 */
	private static final int HASHCODE_TEMPLATE_CONSTANT = 217234;
	
	/**
	 * Private constructor for {@link ColonToken}. Use create(...)-Factory instead!
	 * 
	 * @param position
	 *            represents the start position of the symbol ':' in the original input.
	 */
	private ColonToken(final Position position) {
		super(position, SymbolConstants.COLON);
	}
	
	/**
	 * Factory method for {@link ColonToken}.
	 * 
	 * @param position
	 *            represents the start position of this {@link SymbolToken} in the original input.
	 * @return a new instance of this {@link SymbolToken}.
	 */
	public static ColonToken create(final Position position) {
		return new ColonToken(position);
	}
	
	@Override
	public boolean isColonToken() {
		return true;
	}
	
	@Override
	protected boolean equalsTemplate(final Token t) {
		return t.isColonToken();
	}
	
	@Override
	public String stringRepresentation() {
		return SymbolConstants.COLON;
	}
	
	@Override
	protected int hashCodeTemplate() {
		return HASHCODE_TEMPLATE_CONSTANT;
	}
}
