package de.fhdw.wtf.common.token.symbols;

import de.fhdw.wtf.common.token.Position;
import de.fhdw.wtf.common.token.Token;

/**
 * Represents the curly bracket open '{' symbol as a token.
 */
public final class CurlyBracketOpenToken extends SymbolToken {
	
	/**
	 * generated.
	 */
	private static final long serialVersionUID = -4727963873670581947L;
	
	/**
	 * Defines constant for hashCodeTemplate().
	 */
	private static final int HASHCODE_TEMPLATE_CONSTANT = 7238398;
	
	/**
	 * Private constructor for {@link CurlyBracketOpenToken}. Use create(...)-Factory instead!
	 * 
	 * @param position
	 *            represents the start position of the symbol '{' in the original input.
	 */
	private CurlyBracketOpenToken(final Position position) {
		super(position, SymbolConstants.CURLYBRACKETOPEN);
	}
	
	/**
	 * Factory method for {@link CurlyBracketOpenToken}.
	 * 
	 * @param position
	 *            represents the start position of this {@link SymbolToken} in the original input.
	 * @return a new instance of this {@link SymbolToken}.
	 */
	public static CurlyBracketOpenToken create(final Position position) {
		return new CurlyBracketOpenToken(position);
	}
	
	@Override
	public boolean isCurlyBracketOpenToken() {
		return true;
	}
	
	@Override
	protected boolean equalsTemplate(final Token t) {
		return t.isCurlyBracketOpenToken();
	}
	
	@Override
	public String stringRepresentation() {
		return SymbolConstants.CURLYBRACKETOPEN;
	}
	
	@Override
	protected int hashCodeTemplate() {
		return HASHCODE_TEMPLATE_CONSTANT;
	}
}
