package de.fhdw.wtf.common.token.symbols;

import de.fhdw.wtf.common.token.Position;
import de.fhdw.wtf.common.token.Token;

/**
 * Represents the greater symbol '>' as a token.
 */
public final class GreaterSymbolToken extends SymbolToken {
	
	/**
	 * generated.
	 */
	private static final long serialVersionUID = -7548670933911505424L;
	
	/**
	 * Defines constant for hashCodeTemplate().
	 */
	private static final int HASHCODE_TEMPLATE_CONSTANT = 92389999;
	
	/**
	 * Private constructor for {@link GreaterSymbolToken}. Use create(...)-Factory instead!
	 * 
	 * @param position
	 *            represents the start position of the symbol '>' in the original input.
	 */
	private GreaterSymbolToken(final Position position) {
		super(position, SymbolConstants.GREATERSYMBOL);
	}
	
	/**
	 * Factory method for {@link GreaterSymbolToken}.
	 * 
	 * @param position
	 *            represents the start position of this {@link SymbolToken} in the original input.
	 * @return a new instance of this {@link SymbolToken}.
	 */
	public static GreaterSymbolToken create(final Position position) {
		return new GreaterSymbolToken(position);
	}
	
	@Override
	public boolean isGreaterSymbolToken() {
		return true;
	}
	
	@Override
	protected boolean equalsTemplate(final Token t) {
		return t.isGreaterSymbolToken();
	}
	
	@Override
	public String stringRepresentation() {
		return SymbolConstants.GREATERSYMBOL;
	}
	
	@Override
	protected int hashCodeTemplate() {
		return HASHCODE_TEMPLATE_CONSTANT;
	}
}
