package de.fhdw.wtf.common.token.symbols;

import de.fhdw.wtf.common.token.Position;
import de.fhdw.wtf.common.token.Token;

/**
 * Represents the hyphen symbol '-' as a token.
 */
public final class HyphenToken extends SymbolToken {
	
	/**
	 * generated.
	 */
	private static final long serialVersionUID = -614936132461558955L;
	
	/**
	 * Defines constant for hashCodeTemplate().
	 */
	private static final int HASHCODE_TEMPLATE_CONSTANT = 9833323;
	
	/**
	 * Private constructor for {@link HyphenToken}. Use create(...)-Factory instead!
	 * 
	 * @param position
	 *            represents the start position of the symbol '-' in the original input.
	 */
	private HyphenToken(final Position position) {
		super(position, SymbolConstants.HYPHEN);
	}
	
	/**
	 * Factory method for {@link HyphenToken}.
	 * 
	 * @param position
	 *            represents the start position of this {@link SymbolToken} in the original input.
	 * @return a new instance of this {@link SymbolToken}.
	 */
	public static HyphenToken create(final Position position) {
		return new HyphenToken(position);
	}
	
	@Override
	public boolean isHyphenToken() {
		return true;
	}
	
	@Override
	protected boolean equalsTemplate(final Token t) {
		return t.isHyphenToken();
	}
	
	@Override
	public String stringRepresentation() {
		return SymbolConstants.HYPHEN;
	}
	
	@Override
	protected int hashCodeTemplate() {
		return HASHCODE_TEMPLATE_CONSTANT;
	}
	
}
