package de.fhdw.wtf.common.token.symbols;

import de.fhdw.wtf.common.token.Position;
import de.fhdw.wtf.common.token.Token;

/**
 * Represents the plus symbol '+' as a token.
 */
public final class PlusSymbolToken extends SymbolToken {
	
	/**
	 * generated.
	 */
	private static final long serialVersionUID = 4218535422046007061L;
	
	/**
	 * Defines constant for hashCodeTemplate().
	 */
	private static final int HASHCODE_TEMPLATE_CONSTANT = 98242232;
	
	/**
	 * Private constructor for {@link PlusSymbolToken}. Use create(...)-Factory instead!
	 * 
	 * @param position
	 *            represents the start position of the symbol '+' in the original input.
	 */
	private PlusSymbolToken(final Position position) {
		super(position, SymbolConstants.PLUS);
	}
	
	/**
	 * Factory method for {@link PlusSymbolToken}.
	 * 
	 * @param position
	 *            represents the start position of this {@link SymbolToken} in the original input.
	 * @return a new instance of this {@link SymbolToken}.
	 */
	public static PlusSymbolToken create(final Position position) {
		return new PlusSymbolToken(position);
	}
	
	@Override
	public boolean isPlusSymbolToken() {
		return true;
	}
	
	@Override
	protected boolean equalsTemplate(final Token t) {
		return t.isPlusSymbolToken();
	}
	
	@Override
	public String stringRepresentation() {
		return SymbolConstants.PLUS;
	}
	
	@Override
	protected int hashCodeTemplate() {
		return HASHCODE_TEMPLATE_CONSTANT;
	}
}
