package de.fhdw.wtf.common.token.symbols;

import de.fhdw.wtf.common.token.Position;
import de.fhdw.wtf.common.token.Token;

/**
 * Represents the semicolon symbol ';' as a token.
 */
public final class SemicolonToken extends SymbolToken {
	
	/**
	 * generated.
	 */
	private static final long serialVersionUID = -2387991195143921202L;
	
	/**
	 * Defines constant for hashCodeTemplate().
	 */
	private static final int HASHCODE_TEMPLATE_CONSTANT = 7473834;
	
	/**
	 * Private constructor for {@link SemicolonToken}. Use create(...)-Factory instead!
	 * 
	 * @param position
	 *            represents the start position of the symbol ';' in the original input.
	 */
	private SemicolonToken(final Position position) {
		super(position, SymbolConstants.SEMICOLON);
	}
	
	/**
	 * Factory method for {@link SemicolonToken}.
	 * 
	 * @param position
	 *            represents the start position of this {@link SymbolToken} in the original input.
	 * @return a new instance of this {@link SymbolToken}.
	 */
	public static SemicolonToken create(final Position position) {
		return new SemicolonToken(position);
	}
	
	@Override
	public boolean isSemicolonToken() {
		return true;
	}
	
	@Override
	protected boolean equalsTemplate(final Token t) {
		return t.isSemicolonToken();
	}
	
	@Override
	public String stringRepresentation() {
		return SymbolConstants.SEMICOLON;
	}
	
	@Override
	protected int hashCodeTemplate() {
		return HASHCODE_TEMPLATE_CONSTANT;
	}
}
