package de.fhdw.wtf.common.token.symbols;

import de.fhdw.wtf.common.token.Position;
import de.fhdw.wtf.common.token.Token;

/**
 * Represents the square bracket close symbol ']' as a token.
 */
public final class SquareBracketCloseToken extends SymbolToken {
	
	/**
	 * generated.
	 */
	private static final long serialVersionUID = -8629079034689567533L;
	
	/**
	 * Defines constant for hashCodeTemplate().
	 */
	private static final int HASHCODE_TEMPLATE_CONSTANT = 8273234;
	
	/**
	 * Private constructor for {@link SquareBracketCloseToken}. Use create(...)-Factory instead!
	 * 
	 * @param position
	 *            represents the start position of the symbol ']' in the original input.
	 */
	private SquareBracketCloseToken(final Position position) {
		super(position, SymbolConstants.SQUAREBRACKETCLOSE);
	}
	
	/**
	 * Factory method for {@link SquareBracketCloseToken}.
	 * 
	 * @param position
	 *            represents the start position of this {@link SymbolToken} in the original input.
	 * @return a new instance of this {@link SymbolToken}.
	 */
	public static SquareBracketCloseToken create(final Position position) {
		return new SquareBracketCloseToken(position);
	}
	
	@Override
	public boolean isSquareBracketCloseToken() {
		return true;
	}
	
	@Override
	protected boolean equalsTemplate(final Token t) {
		return t.isSquareBracketCloseToken();
	}
	
	@Override
	public String stringRepresentation() {
		return SymbolConstants.SQUAREBRACKETCLOSE;
	}
	
	@Override
	protected int hashCodeTemplate() {
		return HASHCODE_TEMPLATE_CONSTANT;
	}
}
