package de.fhdw.wtf.parser;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

import de.fhdw.wtf.common.ast.Attribute;
import de.fhdw.wtf.common.ast.AttributeModifier;
import de.fhdw.wtf.common.ast.type.Type;
import de.fhdw.wtf.common.exception.parser.AbstractParserException;
import de.fhdw.wtf.common.stream.TokenStream;
import de.fhdw.wtf.common.token.Token;

/**
 * Parser to parse the given TokenStream to {@link Attribute}s.
 */
final class AttributeParser {
	
	/**
	 * Tokenstream.
	 */
	private final TokenStream stream;
	
	/**
	 * Collection for exceptions.
	 */
	private final Collection<AbstractParserException> exceptions;
	
	/**
	 * Constrcutor of {@link AttributeParser}.
	 * 
	 * @param stream
	 *            tokenstream
	 * @param exceptions
	 *            collection for exceptions
	 */
	private AttributeParser(final TokenStream stream, final Collection<AbstractParserException> exceptions) {
		this.stream = stream;
		this.exceptions = exceptions;
	}
	
	/**
	 * Creates a {@link AttributeParser}-Object.
	 * 
	 * @param stream
	 *            tokenstream
	 * @param exceptions
	 *            collection for exceptions
	 * @return the {@link AttributeParser}-Object.
	 */
	static AttributeParser create(final TokenStream stream, final Collection<AbstractParserException> exceptions) {
		return new AttributeParser(stream, exceptions);
	}
	
	/**
	 * Parses a series of Tokens and creates an Attribute. The name of the attribute will be <code>attributeName</code>.
	 * 
	 * @param attributeName
	 *            attributeName
	 * @param firstToken
	 *            firstToken
	 * @return Attribute
	 * @throws AbstractParserException
	 *             AbstractParserException
	 */
	Attribute parse(final String attributeName, final Token firstToken) throws AbstractParserException {
		final Type attrType = TypeParser.create(this.stream, this.exceptions).parse();
		final List<AttributeModifier> modifiers = new ArrayList<>();
		
		if (!this.stream.peek().isSemicolonToken()) {
			modifiers.addAll(AttributeModifierParser.create(this.stream, this.exceptions).parse());
		}
		
		ParserUtils.requireSemicolonToken(this.stream);
		this.stream.removeFirst();
		final Token lastToken = this.stream.peek();
		
		return Attribute.create(attributeName, attrType, modifiers, firstToken, lastToken);
	}
}
