package de.fhdw.wtf.parser;

import de.fhdw.wtf.common.ast.type.ListType;
import de.fhdw.wtf.common.ast.type.Type;
import de.fhdw.wtf.common.stream.TokenStream;
import de.fhdw.wtf.common.token.Token;

/**
 * Parser to parse the given TokenStream to {@link ListType}s.
 */
final class ListParser {
	
	/**
	 * TokenStream.
	 */
	private final TokenStream stream;
	
	/**
	 * Constructor of {@link ListParser}.
	 * 
	 * @param stream
	 *            tokenStream
	 */
	private ListParser(final TokenStream stream) {
		this.stream = stream;
	}
	
	/**
	 * FactoryMethod for {@link ListParser}.
	 * 
	 * @param stream
	 *            tokenStream
	 * @return The {@link ListParser}-Object.
	 */
	static ListParser create(final TokenStream stream) {
		return new ListParser(stream);
	}
	
	/**
	 * Parses a series of tokens and creates a {@link ListType} from it. If the series of tokens does not match the
	 * grammar an Exception will be thrown.
	 * 
	 * @param firstToken
	 *            firstToken
	 * @param isOf
	 *            isOf-Type
	 * @return ListType
	 */
	ListType parse(final Token firstToken, final Type isOf) {
		ListType current = ListType.create(firstToken, isOf);
		this.stream.removeFirst();
		current.setLastToken(this.stream.peek());
		while (this.stream.hasNext() && this.stream.peek().isAsteriskToken()) {
			final ListType list = ListType.create(firstToken, current);
			this.stream.removeFirst();
			list.setLastToken(this.stream.peek());
			current = list;
		}
		return current;
	}
	
}
